==> AsposeCellsCloud-CellsApi-24.3.tar.gz: AsposeCellsCloud-CellsApi-24.3/docs/SqlScriptSaveOptions.md <==
# AsposeCellsCloud::Object::SqlScriptSaveOptions 

## Load the model package
```perl
use AsposeCellsCloud::Object::SqlScriptSaveOptions;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**CheckIfTableExists** | **boolean** | Check if the table name exists before creating |
**ColumnTypeMap** | **string** | Gets and sets the map of column type for different database. |
**CheckAllDataForColumnType** | **boolean** | Check all data to find columns' data type. |
**AddBlankLineBetweenRows** | **boolean** | Insert blank line between each data. |
**Separator** | **string** | Gets and sets character separator of sql script. |
**OperatorType** | **string** | Gets and sets the operator type of sql. |
**PrimaryKey** | **int** | Represents which column is primary key of the data table. |
**CreateTable** | **boolean** | Indicates whether exporting sql of creating table. |
**IdName** | **string** | Gets and sets the name of id column. |
**StartId** | **int** | Gets and sets the start id. |
**TableName** | **string** | Gets and sets the table name. |
**ExportAsString** | **boolean** | Indicates whether exporting all data as string value. |
**ExportArea** | **CellArea** | Gets or sets the exporting range. |
**HasHeaderRow** | **boolean** | Indicates whether the range contains header row. |
**SaveFormat** | **string** |  |
**CachedFileFolder** | **string** |  |
**ClearData** | **boolean** |  |
**CreateDirectory** | **boolean** |  |
**EnableHTTPCompression** | **boolean** |  |
**RefreshChartCache** | **boolean** |  |
**SortNames** | **boolean** |  |
**ValidateMergedAreas** | **boolean** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-25.4.tar.gz: AsposeCellsCloud-CellsApi-25.4/docs/SqlScriptSaveOptions.md <==
# AsposeCellsCloud::Object::SqlScriptSaveOptions 

## Load the model package
```perl
use AsposeCellsCloud::Object::SqlScriptSaveOptions;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**CheckIfTableExists** | **boolean** | Check if the table name exists before creating |
**ColumnTypeMap** | **string** | Gets and sets the map of column type for different database. |
**CheckAllDataForColumnType** | **boolean** | Check all data to find columns' data type. |
**AddBlankLineBetweenRows** | **boolean** | Insert blank line between each data. |
**Separator** | **string** | Gets and sets character separator of sql script. |
**OperatorType** | **string** | Gets and sets the operator type of sql. |
**PrimaryKey** | **int** | Represents which column is primary key of the data table. |
**CreateTable** | **boolean** | Indicates whether exporting sql of creating table. |
**IdName** | **string** | Gets and sets the name of id column. |
**StartId** | **int** | Gets and sets the start id. |
**TableName** | **string** | Gets and sets the table name. |
**ExportAsString** | **boolean** | Indicates whether exporting all data as string value. |
**ExportArea** | **CellArea** | Gets or sets the exporting range. |
**HasHeaderRow** | **boolean** | Indicates whether the range contains header row. |
**SaveFormat** | **string** |  |
**CachedFileFolder** | **string** |  |
**ClearData** | **boolean** |  |
**CreateDirectory** | **boolean** |  |
**EnableHTTPCompression** | **boolean** |  |
**RefreshChartCache** | **boolean** |  |
**SortNames** | **boolean** |  |
**ValidateMergedAreas** | **boolean** |  |
**MergeAreas** | **boolean** |  |
**SortExternalNames** | **boolean** |  |
**CheckExcelRestriction** | **boolean** |  |
**UpdateSmartArt** | **boolean** |  |
**EncryptDocumentProperties** | **boolean** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
